@@ -63,7 +63,7 @@ for common usecases when using AWS Lambda with Python.
 * :func:`load_urlencoded_body` - auto-deserialize of http body from a querystring encoded body
 * :func:`no_retry_on_failure` - detect and stop retry attempts for scheduled lambdas
 * :func:`ssm_parameter_store` - fetch parameters from the AWS SSM Parameter Store
-* :func:`secret_manager` - fetch secrets from the AWS Secrets Manager
+* :func:`secrets_manager` - fetch secrets from the AWS Secrets Manager
 
 See each individual decorators for specific usage details and the example_
 for some more use cases. This library is also meant to serve as an example for how to write
@@ -132,7 +132,7 @@ just built a few useful decorators and utilities to build them.
 -----
 
 .. |Version| image:: https://img.shields.io/pypi/v/lambda-decorators.svg
-.. _Version: https://pypi.python.org/pypi/lambda-decorators
+.. _Version: https://pypi.org/project/lambda-decorators
 .. |Docs| image:: http://readthedocs.org/projects/lambda-decorators/badge/?version=latest
 .. _Docs: http://lambda-decorators.readthedocs.org/en/latest
 .. |Build| image:: https://img.shields.io/travis/dschep/lambda-decorators/master.svg
@@ -162,10 +162,15 @@ try:
 except ImportError:
     from urlparse import parse_qs
 
+try:
+    basestring
+except NameError:
+    basestring = str
+
 
 logger = logging.getLogger(__name__)
 
-__version__ = '0.2'
+__version__ = "0.2.1"
 
 
 class LambdaDecorator(object):
@@ -206,13 +211,14 @@ class LambdaDecorator(object):
         >>> handler({}, object)
         {'statusCode': 500, 'body': 'uh oh, you broke it'}
     """
+
     def __init__(self, handler):
         update_wrapper(self, handler)
         self.handler = handler
 
     def __call__(self, event, context):
         try:
-            return self.after(self.handler(*self.before(event,  context)))
+            return self.after(self.handler(*self.before(event, context)))
         except Exception as exception:
             return self.on_exception(exception)
 
@@ -252,6 +258,7 @@ def before(func):
         >>> handler({'body': 'BOOODYY'}, object())
         'BOOODYY'
     """
+
     class BeforeDecorator(LambdaDecorator):
         def before(self, event, context):
             return func(event, context)
@@ -277,6 +284,7 @@ def after(func):
         >>> handler({}, object())
         {'body': '', 'Headers': {'X-Clacks-Overhead': 'GNU Terry Pratchett'}}
     """
+
     class AfterDecorator(LambdaDecorator):
         def after(self, retval):
             return func(retval)
@@ -309,6 +317,7 @@ def on_exception(func):
         >>> handler({}, object())
         {'statusCode': 500}
     """
+
     class OnExceptionDecorator(LambdaDecorator):
         def on_exception(self, exception):
             return func(exception)
@@ -338,6 +347,7 @@ def async_handler(handler):
 
     *NOTE: Python 3 only*
     """
+
     @wraps(handler)
     def wrapper(event, context):
         context.loop = asyncio.get_event_loop()
@@ -368,29 +378,34 @@ Usage::
     {'body': 'foobar', 'headers': {'Access-Control-Allow-Origin': 'https://example.com', 'Access-Control-Allow-Credentials': True}}
     """
     if isinstance(handler_or_origin, str) and origin is not None:
-        raise TypeError('You cannot include any positonal arguments when using'
-                        ' the `origin` keyword argument')
+        raise TypeError(
+            "You cannot include any positonal arguments when using"
+            " the `origin` keyword argument"
+        )
     if isinstance(handler_or_origin, str) or origin is not None:
+
         def wrapper_wrapper(handler):
             @wraps(handler)
             def wrapper(event, context):
                 response = handler(event, context)
-                headers = response.setdefault('headers', {})
+                if response is None:
+                    response = {}
+                headers = response.setdefault("headers", {})
                 if origin is not None:
-                    headers['Access-Control-Allow-Origin'] = origin
+                    headers["Access-Control-Allow-Origin"] = origin
                 else:
-                    headers['Access-Control-Allow-Origin'] = handler_or_origin
+                    headers["Access-Control-Allow-Origin"] = handler_or_origin
                 if credentials:
-                    headers['Access-Control-Allow-Credentials'] = True
+                    headers["Access-Control-Allow-Credentials"] = True
                 return response
 
             return wrapper
 
         return wrapper_wrapper
     elif handler_or_origin is None:
-        return cors_headers('*', credentials=credentials)
+        return cors_headers("*", credentials=credentials)
     else:
-        return cors_headers('*')(handler_or_origin)
+        return cors_headers("*")(handler_or_origin)
 
 
 def dump_json_body(handler):
@@ -408,15 +423,17 @@ Usage::
   >>> handler({}, object())
   {'statusCode': 200, 'body': '{"hello": "world"}'}
     """
+
     @wraps(handler)
     def wrapper(event, context):
         response = handler(event, context)
-        if 'body' in response:
+        if "body" in response:
             try:
-                response['body'] = json.dumps(response['body'])
+                response["body"] = json.dumps(response["body"])
             except Exception as exception:
-                return {'statusCode': 500, 'body': str(exception)}
+                return {"statusCode": 500, "body": str(exception)}
         return response
+
     return wrapper
 
 
@@ -442,14 +459,15 @@ in this example, the decorated handler returns:
 
     {'statusCode': 200, 'body': '{"hello": "world"}'}
     """
+
     @wraps(handler)
     def wrapper(event, context):
         response = handler(event, context)
         try:
             body = json.dumps(response)
         except Exception as exception:
-            return {'statusCode': 500, body: str(exception)}
-        return {'statusCode': 200, 'body': body}
+            return {"statusCode": 500, "body": str(exception)}
+        return {"statusCode": 200, "body": body}
 
     return wrapper
 
@@ -472,13 +490,14 @@ def load_json_body(handler):
     note that ``event['body']`` is already a dictionary and didn't have to
     explicitly be parsed.
     """
+
     @wraps(handler)
     def wrapper(event, context):
-        if isinstance(event.get('body'), str):
+        if isinstance(event.get("body"), str):
             try:
-                event['body'] = json.loads(event['body'])
+                event["body"] = json.loads(event["body"])
             except:
-                return {'statusCode': 400, 'body': 'BAD REQUEST'}
+                return {"statusCode": 400, "body": "BAD REQUEST"}
         return handler(event, context)
 
     return wrapper
@@ -510,30 +529,41 @@ def json_schema_validator(request_schema=None, response_schema=None):
       >>> handler({}, object())
       {'statusCode': 500, 'body': "ResponseValidationError: 'bar' is not of type 'number'"}
     """
+
     def wrapper_wrapper(handler):
         @wraps(handler)
         def wrapper(event, context):
             if request_schema is not None:
                 if jsonschema is None:
-                    logger.error('jsonschema is not installed, skipping request validation')
+                    logger.error(
+                        "jsonschema is not installed, skipping request validation"
+                    )
                 else:
                     try:
                         jsonschema.validate(event, request_schema)
                     except jsonschema.ValidationError as exception:
-                        return {'statusCode': 400,
-                                'body': 'RequestValidationError: {}'.format(
-                                    exception.message)}
+                        return {
+                            "statusCode": 400,
+                            "body": "RequestValidationError: {}".format(
+                                exception.message
+                            ),
+                        }
             response = handler(event, context)
             if response_schema is not None:
                 if jsonschema is None:
-                    logger.error('jsonschema is not installed, skipping response validation')
+                    logger.error(
+                        "jsonschema is not installed, skipping response validation"
+                    )
                 else:
                     try:
                         jsonschema.validate(response, response_schema)
                     except jsonschema.ValidationError as exception:
-                        return {'statusCode': 500,
-                                'body': 'ResponseValidationError: {}'.format(
-                                    exception.message)}
+                        return {
+                            "statusCode": 500,
+                            "body": "ResponseValidationError: {}".format(
+                                exception.message
+                            ),
+                        }
             return response
 
         return wrapper
@@ -559,13 +589,14 @@ def load_urlencoded_body(handler):
     note that ``event['body']`` is already a dictionary and didn't have to
     explicitly be parsed.
     """
+
     @wraps(handler)
     def wrapper(event, context):
-        if isinstance(event.get('body'), str):
+        if isinstance(event.get("body"), str):
             try:
-                event['body'] = parse_qs(event['body'])
+                event["body"] = parse_qs(event["body"])
             except:
-                return {'statusCode': 400, 'body': 'BAD REQUEST'}
+                return {"statusCode": 400, "body": "BAD REQUEST"}
         return handler(event, context)
 
     return wrapper
@@ -603,28 +634,29 @@ def no_retry_on_failure(handler):
     @wraps(handler)
     def wrapper(event, context):
         if context.aws_request_id in seen_request_ids:
-            logger.critical('Retry attempt on request id %s detected.',
-                            context.aws_request_id)
-            return {'statusCode': 200}
+            logger.critical(
+                "Retry attempt on request id %s detected.", context.aws_request_id
+            )
+            return {"statusCode": 200}
         seen_request_ids.add(context.aws_request_id)
         return handler(event, context)
 
     return wrapper
 
 
-def ssm_parameter_store(paramters):
+def ssm_parameter_store(*parameters):
     """
-    Get parameters from the AWS SSM Parameter Store.
+    Get parameters from the `AWS SSM Parameter Store <https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-paramstore.html>`_.
 
     Secrets are added to a dictionary named ``ssm_params`` on the context object.
 
-    This requires your lambda to have the ``ssm:GetParameter`` permission on for requested parameters and
+    This requires your lambda to have the ``ssm:GetParameters`` permission on for requested parameters and
     ``kms:Decrypt`` for any keys used to encrypt the parameters.
 
     Usage::
 
-      >>> from lambda_decorators import secret_manager
-      >>> @ssm_parameter_store(['/dschep/test'])
+      >>> from lambda_decorators import ssm_parameter_store
+      >>> @ssm_parameter_store('/dschep/test')
       ... def param_getter(event, context):
       ...     return context.parameters
       >>> class Context:
@@ -635,13 +667,65 @@ def ssm_parameter_store(paramters):
     For more advanced SSM use, see `ssm-cache <https://github.com/alexcasalboni/ssm-cache-python>`_
 
     """
+    # support old list as 1st argument invocation style
+    if len(parameters) == 1 and not isinstance(parameters[0], basestring):
+        parameters = parameters[0]
+
     def wrapper_wrapper(handler):
         @wraps(handler)
         def wrapper(event, context):
-            if not hasattr(context, 'parameters'):
+            ssm = boto3.client("ssm")
+            if not hasattr(context, "parameters"):
                 context.parameters = {}
-            for parameter in boto3.client('ssm').get_parameters(Names=paramters, WithDecryption=True)['Parameters']:
-                context.parameters[parameter['Name']] = parameter['Value']
+            for parameter in ssm.get_parameters(Names=parameters, WithDecryption=True)[
+                "Parameters"
+            ]:
+                context.parameters[parameter["Name"]] = parameter["Value"]
+
+            return handler(event, context)
+
+        return wrapper
+
+    return wrapper_wrapper
+
+
+def secrets_manager(*secret_names):
+    """
+    Get secrets from the `AWS Secrets Manager <https://aws.amazon.com/secrets-manager/>`_.
+
+    Secrets are added to a dictionary named ``secrets`` on the context object.
+
+    This requires your lambda to have the ``secretsmanager:GetSecretValue`` permission for the
+    requested secret and ``kms:Decrypt`` for any keys used to encrypt the secrets.
+
+    Usage::
+
+      >>> from lambda_decorators import secrets_manager
+      >>> @secrets_manager('dschep/test')
+      ... def secret_getter(event, context):
+      ...     return context.secrets
+      >>> class Context:
+      ...     pass
+      >>> secret_getter({}, Context())
+      {'dschep/test': {'foo': 'b4r', 'floo': 'b4z'}}
+
+    """
+
+    def wrapper_wrapper(handler):
+        @wraps(handler)
+        def wrapper(event, context):
+            if not hasattr(context, "secrets"):
+                context.secrets = {}
+            for secret_name in secret_names:
+                secret_value = boto3.client(
+                    service_name="secretsmanager"
+                ).get_secret_value(SecretId=secret_name)
+                if "SecretString" in secret_value:
+                    context.secrets[secret_name] = json.loads(
+                        secret_value["SecretString"]
+                    )
+                else:
+                    context.secrets[secret_name] = secret_value["SecretBinary"]
 
             return handler(event, context)
 
@@ -654,35 +738,7 @@ def secret_manager(secret_name):
     """
     Get a secret value from the AWS Secret Manager.
 
-    Secrets are added to a dictionary named ``secrets`` on the context object.
-
-    This requires your lambda to have the ``secretsmanager:GetSecretValue`` permission for the requested secret.
-
-    Usage::
-
-      >>> from lambda_decorators import secret_manager
-      >>> @secret_manager('dschep/test')
-      ... def secret_getter(event, context):
-      ...     return context.secrets
-      >>> class Context:
-      ...     pass
-      >>> secret_getter({}, Context())
-      {'dschep/test': {'foo': 'b4r', 'floo': 'b4z'}}
-
+    .. deprecated:: 0.3
+    Use the better spelled secrets_manager
     """
-    def wrapper_wrapper(handler):
-        @wraps(handler)
-        def wrapper(event, context):
-            secret_value = boto3.client(service_name='secretsmanager').get_secret_value(SecretId=secret_name)
-            if not hasattr(context, 'secrets'):
-                context.secrets = {}
-            if 'SecretString' in secret_value:
-                context.secrets[secret_name] = json.loads(secret_value['SecretString'])
-            else:
-                context.secrets[secret_name] = secret_value['SecretBinary']
-
-            return handler(event, context)
-
-        return wrapper
-
-    return wrapper_wrapper
+    return secrets_manager(secret_name)
